@@ -30,7 +30,15 @@ my $g = $mw->RotatingGauge(
     -visible => $v,
     -value   => $val,
 )->pack(-side=>'left', -expand=>1, -fill=>'both');
-$mw->Button(-command=>\&plus,  -text=> '+')->pack(-side=>'right');
+$mw->Button(-command=>\&plus,  -text=> '+')->pack(-side=>'left');
+my $policy = 'rotate';
+$mw->Checkbutton(
+    -text     => 'strict',
+    -variable => \$policy,
+    -onvalue  => 'strict',
+    -offvalue => 'rotate',
+    -command  => sub { $g->configure(-policy=>$policy); },
+)->pack(-side=>'left');
 
 MainLoop;
 exit;
